==> kubernetes-model-apps-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetOrdinalsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StatefulSetOrdinalsFluentImpl<A extends StatefulSetOrdinalsFluent<A>> extends BaseFluent<A> implements StatefulSetOrdinalsFluent<A>{
  public StatefulSetOrdinalsFluentImpl() {
  }
  public StatefulSetOrdinalsFluentImpl(StatefulSetOrdinals instance) {
    this.withStart(instance.getStart()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer start;
  private Map<String,Object> additionalProperties;
  public Integer getStart() {
    return this.start;
  }
  public A withStart(Integer start) {
    this.start=start; return (A) this;
  }
  public Boolean hasStart() {
    return this.start != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StatefulSetOrdinalsFluentImpl that = (StatefulSetOrdinalsFluentImpl) o;
    if (start != null ? !start.equals(that.start) :that.start != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(start,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (start != null) { sb.append("start:"); sb.append(start + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-apps-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetOrdinalsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StatefulSetOrdinalsFluentImpl<A extends StatefulSetOrdinalsFluent<A>> extends BaseFluent<A> implements StatefulSetOrdinalsFluent<A>{
  public StatefulSetOrdinalsFluentImpl() {
  }
  public StatefulSetOrdinalsFluentImpl(StatefulSetOrdinals instance) {
    if (instance != null) {
      this.withStart(instance.getStart());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer start;
  private Map<String,Object> additionalProperties;
  public Integer getStart() {
    return this.start;
  }
  public A withStart(Integer start) {
    this.start=start; return (A) this;
  }
  public Boolean hasStart() {
    return this.start != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetOrdinalsFluentImpl that = (StatefulSetOrdinalsFluentImpl) o;
    if (!java.util.Objects.equals(start, that.start)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(start,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (start != null) { sb.append("start:"); sb.append(start + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
